@@ -69,7 +69,12 @@ def split_body_parts(num_parts,body_parts):
         parts_dict[part]['title'] = MDRenderer().render(tokens[ptt[0]+1:ptt[1]], mdit.options, env).strip('\n')
 
         pa = [i for i,j in enumerate(tokens) if j.tag=='h3']
-        parts_dict[part]['answer']['title'] = MDRenderer().render(tokens[pa[0]+1:pa[1]], mdit.options, env)
+
+        try:
+            parts_dict[part]['answer']['title'] = MDRenderer().render(tokens[pa[0]+1:pa[1]], mdit.options, env)
+        except IndexError:
+            print("Check the heading level of 'Answer Section', it should be ### Answer Section.")
+            raise
 
         parts_dict[part]['content'] = MDRenderer().render(tokens[ptt[1]+1:pa[0]], mdit.options, env)
         parts_dict[part]['answer']['content'] = MDRenderer().render(tokens[pa[1]+1:], mdit.options, env)
@@ -243,7 +248,7 @@ def process_multiple_choice(part_name,parsed_question, data_dict):
         str: Multiple choice question is returned as a string with PL-compliant syntax.
     """
 
-    html = f"""<pl-question-panel>\n\t<markdown>{parsed_question['body_parts_split'][part_name]['content']}\t</markdown>\n</pl-question-panel>\n\n"""
+    html = f"""<pl-question-panel>\n<markdown>{parsed_question['body_parts_split'][part_name]['content']}</markdown>\n</pl-question-panel>\n\n"""
     
     pl_customizations = " ".join([f'{k} = "{v}"' for k,v in parsed_question['header'][part_name]['pl-customizations'].items()]) # PL-customizations
     html += f"""<pl-multiple-choice answers-name="{part_name}_ans" {pl_customizations} >\n"""
@@ -339,6 +344,30 @@ def replace_tags(string):
     """
     return string.replace('|@','{{').replace('@|','}}')
 
+def process_attribution(source):
+    """Takes in a string and returns the HTML for the attribution
+
+    Args:
+        source (string): One of a set of pre-defined values corresponding to a particular attribution.
+
+    Returns:
+        string (str): returns the html of the attribution
+    """
+
+    if source == 'openstax-physics-vol1':
+        attribution_text = "![Image representing the Creative Commons 4.0 BY license.](https://i.creativecommons.org/l/by/4.0/88x31.png) Problem is from the [OpenStax University Physics Volume 1](https://openstax.org/details/books/university-physics-volume-1) textbook, licensed under the [CC-BY 4.0 license](https://creativecommons.org/licenses/by/4.0/)."
+
+    elif source == 'openstax-physics-vol2':
+        attribution_text = "![Image representing the Creative Commons 4.0 BY license.](https://i.creativecommons.org/l/by/4.0/88x31.png) Problem is from the [OpenStax University Physics Volume 2](https://openstax.org/details/books/university-physics-volume-2) textbook, licensed under the [CC-BY 4.0 license](https://creativecommons.org/licenses/by/4.0/)."
+
+    elif source == 'ubc-mech2':
+        raise NotImplementedError
+
+    elif source is None or source =='standard':
+        attribution_text = "![Image representing the Creative Commons 4.0 BY-NC-SA license.](https://mirrors.creativecommons.org/presskit/buttons/88x31/png/by-nc-sa.png) Problem is licensed under the [CC-BY-NC-SA 4.0 license](https://creativecommons.org/licenses/by-nc-sa/4.0/)."
+
+    return attribution_text
+
 def process_question(input_file, output_path):
 
     try:
@@ -409,8 +438,10 @@ def process_question(input_file, output_path):
 
             question_html += "</div>\n</div>\n\n"
 
-    # Write question.html file
+    # Add Attribution
+    question_html += f"\n\n---<markdown>\n{process_attribution(parsed_q['header'].get('attribution'))}\n</markdown>"
 
+    # Write question.html file
     (output_path / "question.html").write_text(question_html)
 
     # Write server.py file
